@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,16 +22,11 @@
 #include <KLocalizedString>
 
 using namespace KSieveUi;
-SieveActionAddFlags::SieveActionAddFlags(QObject *parent)
-    : SieveActionAbstractFlags(QStringLiteral("addflag"), i18n("Add Flags"), parent)
+SieveActionAddFlags::SieveActionAddFlags(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveActionAbstractFlags(sieveGraphicalModeWidget, QStringLiteral("addflag"), i18n("Add Flags"), parent)
 {
 }
 
-SieveAction *SieveActionAddFlags::newAction()
-{
-    return new SieveActionAddFlags;
-}
-
 QString SieveActionAddFlags::flagsCode() const
 {
     return QStringLiteral("addflag");
