@@ -26,7 +26,7 @@
 
 #include <QWidget>
 #include <QLabel>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 #include <QGridLayout>
 
@@ -67,46 +67,55 @@ QWidget *SieveActionDeleteHeader::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionDeleteHeader::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
+bool SieveActionDeleteHeader::parseValue(QXmlStreamReader &element, QWidget *w, QString &error, bool isNegative)
 {
     int index = 0;
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("test")) {
-                QDomNode testNode = e.toElement();
-                return setParamWidgetValue(testNode.toElement(), w, error);
-            } else if (tagName == QLatin1String("tag")) {
-                SelectMatchTypeComboBox *combo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
-                combo->setCode(AutoCreateScriptUtil::tagValue(e.text()), name(), error);
-            } else if (tagName == QLatin1String("str")) {
-                if (index == 0) {
-                    QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
-                    edit->setText(e.text());
-                } else if (index == 1) {
-                    QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
-                    value->setText(e.text());
-                } else {
-                    tooManyArgument(tagName, index, 2, error);
-                    qCDebug(LIBKSIEVE_LOG) << " SieveActionAddHeader::setParamWidgetValue too many argument :" << index;
-                }
-                ++index;
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
-            } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << "SieveActionAddHeader::setParamWidgetValue unknown tag " << tagName;
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("test")) {
+            QString nameValue;
+            if (element.attributes().hasAttribute(QStringLiteral("name"))) {
+                nameValue = element.attributes().value(QStringLiteral("name")).toString();
             }
+            const bool isNegative = (nameValue == QLatin1String("not"));
+            bool result = parseValue(element, w, error, isNegative);
+            element.skipCurrentElement();
+            return result;
+        } else if (tagName == QLatin1String("tag")) {
+            SelectMatchTypeComboBox *combo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            combo->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), isNegative), name(), error);
+        } else if (tagName == QLatin1String("str")) {
+            if (index == 0) {
+                QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
+                edit->setText(element.readElementText());
+            } else if (index == 1) {
+                QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
+                value->setText(element.readElementText());
+            } else {
+                tooManyArgument(tagName, index, 2, error);
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionAddHeader::setParamWidgetValue too many argument :" << index;
+            }
+            ++index;
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            element.skipCurrentElement();
+            //implement in the future ?
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << "SieveActionAddHeader::setParamWidgetValue unknown tag " << tagName;
         }
-        node = node.nextSibling();
     }
+
     return true;
 }
 
+bool SieveActionDeleteHeader::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+{
+    return parseValue(element, w, error, false);
+}
+
 QString SieveActionDeleteHeader::code(QWidget *w) const
 {
     const SelectMatchTypeComboBox *combo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
@@ -132,3 +141,8 @@ QUrl SieveActionDeleteHeader::href() const
     return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
 }
 
+QStringList SieveActionDeleteHeader::needRequires(QWidget *w) const
+{
+    const SelectMatchTypeComboBox *combo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+    return SieveActionAbstractEditHeader::needRequires(w) + combo->needRequires();
+}
