@@ -24,7 +24,7 @@
 
 #include <QLabel>
 #include <QSpinBox>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 #include <QGridLayout>
 
@@ -62,32 +62,32 @@ QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionExtractText::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
+bool SieveActionExtractText::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("tag")) {
-                //TODO ?
-            } else if (tagName == QLatin1String("num")) {
-                QSpinBox *numberOfCharacters = w->findChild<QSpinBox *>(QStringLiteral("numberOfCharacters"));
-                numberOfCharacters->setValue(e.text().toInt());
-            } else if (tagName == QLatin1String("str")) {
-                QLineEdit *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
-                variableName->setText(e.text());
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
-            } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << " SieveActionExtractText::setParamWidgetValue unknown tagName " << tagName;
-            }
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+
+        if (tagName == QLatin1String("tag")) {
+            element.skipCurrentElement();
+            //TODO ?
+        } else if (tagName == QLatin1String("num")) {
+            QSpinBox *numberOfCharacters = w->findChild<QSpinBox *>(QStringLiteral("numberOfCharacters"));
+            numberOfCharacters->setValue(element.readElementText().toInt());
+        } else if (tagName == QLatin1String("str")) {
+            QLineEdit *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
+            variableName->setText(element.readElementText());
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            element.skipCurrentElement();
+            //implement in the future ?
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveActionExtractText::setParamWidgetValue unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
+
     return true;
 }
 
@@ -127,4 +127,3 @@ QUrl SieveActionExtractText::href() const
 {
     return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
 }
-
