@@ -38,22 +38,16 @@
 #include <QWhatsThis>
 #include <QDomElement>
 
+#include <autocreatescripts/sieveactions/sieveactionsetvariable.h>
+
 using namespace KSieveUi;
 
 static int MINIMUMACTION = 1;
 static int MAXIMUMACTION = 8;
 
-namespace
-{
-inline const QString indentation()
-{
-    return QStringLiteral("    ");
-}
-}
-
 SieveActionWidget::SieveActionWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent)
-    : QWidget(parent),
-      mSieveGraphicalModeWidget(graphicalModeWidget)
+    : QWidget(parent)
+    , mSieveGraphicalModeWidget(graphicalModeWidget)
 {
     initWidget();
 }
@@ -66,7 +60,7 @@ SieveActionWidget::~SieveActionWidget()
 
 bool SieveActionWidget::isConfigurated() const
 {
-    return (mComboBox->currentIndex() != (mComboBox->count() - 1));
+    return mComboBox->currentIndex() != (mComboBox->count() - 1);
 }
 
 void SieveActionWidget::setFilterAction(QWidget *widget)
@@ -82,7 +76,7 @@ void SieveActionWidget::setFilterAction(QWidget *widget)
     }
 }
 
-void SieveActionWidget::generatedScript(QString &script, QStringList &requires, bool onlyActions)
+void SieveActionWidget::generatedScript(QString &script, QStringList &requires, bool onlyActions, bool inForEveryPartLoop)
 {
     const int index = mComboBox->currentIndex();
     if (index != mComboBox->count() - 1) {
@@ -95,10 +89,25 @@ void SieveActionWidget::generatedScript(QString &script, QStringList &requires,
             }
         }
         QString comment = widgetAction->comment();
-        if (!comment.isEmpty()) {
-            script += (onlyActions ? QString() : indentation()) + QLatin1Char('#') + comment.replace(QLatin1Char('\n'), QStringLiteral("\n#")) + QLatin1Char('\n');
+        QString indent;
+        if (!onlyActions) {
+            indent += AutoCreateScriptUtil::indentation();
         }
-        script += (onlyActions ? QString() : indentation()) + widgetAction->code(currentWidget) + QLatin1Char('\n');
+        if (inForEveryPartLoop) {
+            indent += AutoCreateScriptUtil::indentation();
+        }
+        if (!comment.trimmed().isEmpty()) {
+            const QStringList commentList = comment.split(QLatin1Char('\n'));
+
+            for (const QString &str : commentList) {
+                if (str.isEmpty()) {
+                    script += QLatin1Char('\n');
+                } else {
+                    script += indent + QLatin1Char('#') + str + QLatin1Char('\n');
+                }
+            }
+        }
+        script += indent + widgetAction->code(currentWidget) + QLatin1Char('\n');
     }
 }
 
@@ -139,19 +148,16 @@ void SieveActionWidget::initWidget()
     }
 
     mHelpButton = new SieveHelpButton(this);
-    mHelpButton->setEnabled(false);
     connect(mHelpButton, &SieveHelpButton::clicked, this, &SieveActionWidget::slotHelp);
     mLayout->addWidget(mHelpButton, 1, 0);
 
     mCommentButton = new QToolButton(this);
     mCommentButton->setToolTip(i18n("Add comment"));
-    mCommentButton->setEnabled(false);
     mLayout->addWidget(mCommentButton, 1, 1);
     mCommentButton->setIcon(QIcon::fromTheme(QStringLiteral("view-pim-notes")));
     connect(mCommentButton, &QToolButton::clicked, this, &SieveActionWidget::slotAddComment);
 
     mComboBox->addItem(QLatin1String(""));
-    mComboBox->setCurrentIndex(mComboBox->count() - 1);
 
     mComboBox->setMaxCount(mComboBox->count());
     mComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
@@ -178,7 +184,8 @@ void SieveActionWidget::initWidget()
 
     connect(mAdd, &QPushButton::clicked, this, &SieveActionWidget::slotAddWidget);
     connect(mRemove, &QPushButton::clicked, this, &SieveActionWidget::slotRemoveWidget);
-    setFilterAction(nullptr);
+
+    clear();
 }
 
 void SieveActionWidget::slotHelp()
@@ -193,6 +200,14 @@ void SieveActionWidget::slotHelp()
     }
 }
 
+void SieveActionWidget::clear()
+{
+    mComboBox->setCurrentIndex(mComboBox->count() - 1);
+    setFilterAction(nullptr);
+    mCommentButton->setEnabled(false);
+    mHelpButton->setEnabled(false);
+}
+
 void SieveActionWidget::slotAddComment()
 {
     const int index = mComboBox->currentIndex();
@@ -246,7 +261,24 @@ void SieveActionWidget::updateAddRemoveButton(bool addButtonEnabled, bool remove
     mRemove->setEnabled(removeButtonEnabled);
 }
 
-bool SieveActionWidget::setAction(const QString &actionName, const QDomElement &element, const QString &comment, QString &error)
+void SieveActionWidget::setLocaleVariable(const SieveGlobalVariableActionWidget::VariableElement &var)
+{
+    const int index = mComboBox->findData(QStringLiteral("set"));
+    if (index != -1) {
+        mComboBox->setCurrentIndex(index);
+        slotActionChanged(index);
+        KSieveUi::SieveActionSetVariable *localVar = dynamic_cast<KSieveUi::SieveActionSetVariable *>(mActionList.at(index));
+        if (localVar) {
+            localVar->setLocalVariable(this, var);
+        }
+    } else {
+        //error += i18n("Script contains unsupported feature \"%1\"", actionName) + QLatin1Char('\n');
+        //qCDebug(LIBKSIEVE_LOG) << "Action " << actionName << " not supported";
+    }
+
+}
+
+bool SieveActionWidget::setAction(const QString &actionName, QXmlStreamReader &element, const QString &comment, QString &error)
 {
     const int index = mComboBox->findData(actionName);
     bool result = false;
@@ -256,13 +288,17 @@ bool SieveActionWidget::setAction(const QString &actionName, const QDomElement &
         KSieveUi::SieveAction *action = mActionList.at(index);
         result = action->setParamWidgetValue(element, this, error);
         action->setComment(comment);
+    } else {
+        error += i18n("Script contains unsupported feature \"%1\"", actionName) + QLatin1Char('\n');
+        qCDebug(LIBKSIEVE_LOG) << "Action " << actionName << " not supported";
+        element.skipCurrentElement();
     }
     return result;
 }
 
 SieveActionWidgetLister::SieveActionWidgetLister(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent)
-    : KPIM::KWidgetLister(false, MINIMUMACTION, MAXIMUMACTION, parent),
-      mSieveGraphicalModeWidget(graphicalModeWidget)
+    : KPIM::KWidgetLister(false, MINIMUMACTION, MAXIMUMACTION, parent)
+    , mSieveGraphicalModeWidget(graphicalModeWidget)
 {
     slotClear();
     updateAddRemoveButton();
@@ -270,7 +306,6 @@ SieveActionWidgetLister::SieveActionWidgetLister(SieveEditorGraphicalModeWidget
 
 SieveActionWidgetLister::~SieveActionWidgetLister()
 {
-
 }
 
 void SieveActionWidgetLister::slotAddWidget(QWidget *w)
@@ -309,14 +344,14 @@ void SieveActionWidgetLister::updateAddRemoveButton()
     }
 }
 
-void SieveActionWidgetLister::generatedScript(QString &script, QStringList &requires, bool onlyActions)
+void SieveActionWidgetLister::generatedScript(QString &script, QStringList &requires, bool onlyActions, bool inForEveryPartLoop)
 {
     const QList<QWidget *> widgetList = widgets();
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
         SieveActionWidget *w = qobject_cast<SieveActionWidget *>(*wIt);
-        w->generatedScript(script, requires, onlyActions);
+        w->generatedScript(script, requires, onlyActions, inForEveryPartLoop);
     }
 }
 
@@ -329,9 +364,11 @@ void SieveActionWidgetLister::reconnectWidget(SieveActionWidget *w)
 
 void SieveActionWidgetLister::clearWidget(QWidget *aWidget)
 {
-    Q_UNUSED(aWidget);
+    if (aWidget) {
+        SieveActionWidget *widget = static_cast<SieveActionWidget *>(aWidget);
+        widget->clear();
+    }
     Q_EMIT valueChanged();
-    //TODO
 }
 
 QWidget *SieveActionWidgetLister::createWidget(QWidget *parent)
@@ -346,67 +383,80 @@ int SieveActionWidgetLister::actionNumber() const
     return widgets().count();
 }
 
-void SieveActionWidgetLister::loadScript(const QDomElement &element, bool onlyActions, QString &error)
+void SieveActionWidgetLister::loadLocalVariable(const SieveGlobalVariableActionWidget::VariableElement &var)
+{
+    SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+    if (w->isConfigurated()) {
+        addWidgetAfterThisWidget(widgets().constLast());
+        w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+    }
+    w->setLocaleVariable(var);
+
+}
+
+void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyActions, QString &error)
 {
     QString comment;
     if (onlyActions) {
-        if (!element.isNull()) {
-            const QString tagName = element.tagName();
-            if (tagName == QLatin1String("action")) {
-                if (element.hasAttribute(QStringLiteral("name"))) {
-                    const QString actionName = element.attribute(QStringLiteral("name"));
-                    SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
-                    if (w->isConfigurated()) {
-                        addWidgetAfterThisWidget(widgets().constLast());
-                        w = qobject_cast<SieveActionWidget *>(widgets().constLast());
-                    }
-                    w->setAction(actionName, element, comment, error);
-                    //comment.clear();
-                } else if (tagName == QLatin1String("crlf")) {
-                    //nothing
-                } else {
-                    qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript don't have name attribute " << tagName;
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("action")) {
+            if (element.attributes().hasAttribute(QStringLiteral("name"))) {
+                const QString actionName = element.attributes().value(QStringLiteral("name")).toString();
+                SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+                if (w->isConfigurated()) {
+                    addWidgetAfterThisWidget(widgets().constLast());
+                    w = qobject_cast<SieveActionWidget *>(widgets().constLast());
                 }
+                w->setAction(actionName, element, comment, error);
+                //comment.clear();
+            } else if (tagName == QLatin1String("crlf")) {
+                element.skipCurrentElement();
+                //nothing
+            } else {
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript don't have name attribute " << tagName;
             }
+        } else {
+            qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript Unknow tag name " << tagName;
         }
     } else {
         bool firstAction = true;
-        QDomNode node = element.firstChild();
-        while (!node.isNull()) {
-            QDomElement e = node.toElement();
-            if (!e.isNull()) {
-                const QString tagName = e.tagName();
-                if (tagName == QLatin1String("action") || tagName == QLatin1String("control")/*for break action*/) {
-                    if (e.hasAttribute(QStringLiteral("name"))) {
-                        const QString actionName = e.attribute(QStringLiteral("name"));
-                        if (tagName == QLatin1String("control") && actionName == QLatin1String("if")) {
-                            qCDebug(LIBKSIEVE_LOG) << "We found an loop if in a loop if. Not supported";
-                            error += i18n("We detected a loop if in a loop if. It's not supported") + QLatin1Char('\n');
-                        }
-                        if (firstAction) {
-                            firstAction = false;
-                        } else {
-                            addWidgetAfterThisWidget(widgets().constLast());
-                        }
-                        SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
-                        w->setAction(actionName, e, comment, error);
-                        comment.clear();
+        bool previousActionWasAComment = false;
+        while (element.readNextStartElement()) {
+            const QStringRef tagName = element.name();
+            if (tagName == QLatin1String("action") || tagName == QLatin1String("control") /*for break action*/) {
+                if (element.attributes().hasAttribute(QStringLiteral("name"))) {
+                    const QString actionName = element.attributes().value(QStringLiteral("name")).toString();
+                    if (tagName == QLatin1String("control") && actionName == QLatin1String("if")) {
+                        qCDebug(LIBKSIEVE_LOG) << "We found an loop if in a loop if. Not supported";
+                        error += i18n("We detected a loop if in a loop if. It's not supported") + QLatin1Char('\n');
+                    }
+                    if (firstAction) {
+                        firstAction = false;
                     } else {
-                        qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript don't have name attribute " << tagName;
+                        addWidgetAfterThisWidget(widgets().constLast());
                     }
-                } else if (tagName == QLatin1String("comment")) {
-                    if (!comment.isEmpty()) {
-                        comment += QLatin1Char('\n');
-                    }
-                    comment += e.text();
-                } else if (tagName == QLatin1String("crlf")) {
-                    //nothing
+                    SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+                    w->setAction(actionName, element, comment, error);
+                    comment.clear();
                 } else {
-                    qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript unknown tagName " << tagName;
+                    qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript don't have name attribute " << tagName;
                 }
+                previousActionWasAComment = false;
+            } else if (tagName == QLatin1String("comment")) {
+                if (!comment.isEmpty()) {
+                    comment += QLatin1Char('\n');
+                }
+                previousActionWasAComment = true;
+                comment += element.readElementText();
+            } else if (tagName == QLatin1String("crlf")) {
+                //Add new line if previous action was a comment
+                if (previousActionWasAComment) {
+                    comment += QLatin1Char('\n');
+                }
+                element.skipCurrentElement();
+            } else {
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript unknown tagName " << tagName;
             }
-            node = node.nextSibling();
         }
     }
 }
-
