@@ -22,9 +22,8 @@
 
 #include <QObject>
 #include <QUrl>
-class QDomElement;
-namespace KSieveUi
-{
+class QXmlStreamReader;
+namespace KSieveUi {
 class SieveEditorGraphicalModeWidget;
 class SieveCondition : public QObject
 {
@@ -54,13 +53,20 @@ public:
     virtual QString help() const;
     virtual QUrl href() const;
 
-    virtual bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error);
+    virtual bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, bool notCondition, QString &error);
 
-    void unknownTag(const QString &tag, QString &error);
+    void unknownTag(const QStringRef &tag, QString &error);
     void unknowTagValue(const QString &tagValue, QString &error);
+    void tooManyArgument(const QStringRef &tagName, int index, int maxValue, QString &error);
     void tooManyArgument(const QString &tagName, int index, int maxValue, QString &error);
     void serverDoesNotSupportFeatures(const QString &feature, QString &error);
 
+    QString comment() const;
+
+    void setComment(const QString &comment);
+
+    QString generateComment() const;
+
 protected:
     QStringList sieveCapabilities() const;
     SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget;
@@ -71,6 +77,7 @@ Q_SIGNALS:
 private:
     QString mName;
     QString mLabel;
+    QString mComment;
 };
 }
 
