@@ -20,33 +20,32 @@
 #ifndef SIEVEEDITORGRAPHICALMODEWIDGET_H
 #define SIEVEEDITORGRAPHICALMODEWIDGET_H
 
-#include "editor/sieveeditorabstractwidget.h"
+#include "sieveeditorgraphicalmodewidgetabstract.h"
 #include "util/sieveimapaccountsettings.h"
+#include "ksieveui_private_export.h"
 class QSplitter;
 class QStackedWidget;
-class QDomDocument;
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveScriptPage;
 class SieveScriptListBox;
 class SieveEditorParsingMissingFeatureWarning;
-class SieveEditorGraphicalModeWidget : public SieveEditorAbstractWidget
+class KSIEVEUI_TESTS_EXPORT SieveEditorGraphicalModeWidget : public SieveEditorGraphicalModeWidgetAbstract
 {
     Q_OBJECT
 public:
     explicit SieveEditorGraphicalModeWidget(QWidget *parent = nullptr);
     ~SieveEditorGraphicalModeWidget();
 
-    QString script(QString &requires) const;
+    QString script(QString &requires) const override;
 
-    void setSieveCapabilities(const QStringList &capabilities);
-    QStringList sieveCapabilities();
+    void setSieveCapabilities(const QStringList &capabilities) override;
+    QStringList sieveCapabilities() override;
 
-    void loadScript(const QDomDocument &doc, QString &error);
+    void loadScript(const QString &doc, QString &error) override;
 
-    QString currentscript() Q_DECL_OVERRIDE;
-    void setImportScript(const QString &) Q_DECL_OVERRIDE;
+    QString currentscript() override;
+    void setImportScript(const QString &) override;
 
 Q_SIGNALS:
     void enableButtonOk(bool);
