@@ -27,10 +27,9 @@ class QPushButton;
 class QLineEdit;
 class QGridLayout;
 class QCheckBox;
-class QDomElement;
+class QXmlStreamReader;
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveHelpButton;
 class SieveGlobalVariableWidget;
 
@@ -38,16 +37,25 @@ class SieveGlobalVariableActionWidget : public QWidget
 {
     Q_OBJECT
 public:
+    struct VariableElement {
+        QString variableName;
+        QString variableValue;
+        bool isValid() const {
+            return !variableName.isEmpty();
+        }
+    };
+
     explicit SieveGlobalVariableActionWidget(QWidget *parent = nullptr);
     ~SieveGlobalVariableActionWidget();
 
     void generatedScript(QString &script);
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
     bool isInitialized() const;
-    void loadScript(const QDomElement &element, QString &error);
+    void loadScript(QXmlStreamReader &element, QString &error);
     void setVariableValue(const QString &name);
     QString variableName() const;
 
+    void clear();
 private Q_SLOTS:
     void slotAddWidget();
     void slotRemoveWidget();
@@ -75,8 +83,8 @@ public:
     ~SieveGlobalVariableLister();
 
     void generatedScript(QString &script, QStringList &requires);
-    void loadScript(const QDomElement &element, QString &error);
-    void loadSetVariable(const QDomElement &element, QString &error);
+    void loadScript(QXmlStreamReader &element, QString &error);
+    SieveGlobalVariableActionWidget::VariableElement loadSetVariable(QXmlStreamReader &element, QString &error);
 
 Q_SIGNALS:
     void valueChanged();
@@ -86,8 +94,8 @@ public Q_SLOTS:
     void slotRemoveWidget(QWidget *w);
 
 protected:
-    void clearWidget(QWidget *aWidget) Q_DECL_OVERRIDE;
-    QWidget *createWidget(QWidget *parent) Q_DECL_OVERRIDE;
+    void clearWidget(QWidget *aWidget) override;
+    QWidget *createWidget(QWidget *parent) override;
 private:
     void reconnectWidget(SieveGlobalVariableActionWidget *w);
     void updateAddRemoveButton();
@@ -100,10 +108,10 @@ public:
     explicit SieveGlobalVariableWidget(QWidget *parent = nullptr);
     ~SieveGlobalVariableWidget();
 
-    void generatedScript(QString &script, QStringList &requires) Q_DECL_OVERRIDE;
+    void generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop) override;
 
-    void loadScript(const QDomElement &element, QString &error);
-    void loadSetVariable(const QDomElement &element, QString &error);
+    void loadScript(QXmlStreamReader &element, QString &error);
+    SieveGlobalVariableActionWidget::VariableElement loadSetVariable(QXmlStreamReader &element, QString &error);
 
 private Q_SLOTS:
     void slotHelp();
