@@ -20,13 +20,14 @@
 #include "sievescriptblockwidget.h"
 #include "sieveactionwidgetlister.h"
 #include "sieveconditionwidgetlister.h"
+#include "autocreatescriptutil_p.h"
 
 #include <KLocalizedString>
 #include <KComboBox>
 #include <QPushButton>
 #include <QIcon>
 
-#include <QDomElement>
+#include <QXmlStreamReader>
 #include <QVBoxLayout>
 #include <QGroupBox>
 #include <QButtonGroup>
@@ -37,9 +38,9 @@
 using namespace KSieveUi;
 
 SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent)
-    : SieveWidgetPageAbstract(parent),
-      mMatchCondition(AndCondition),
-      mSieveGraphicalModeWidget(graphicalModeWidget)
+    : SieveWidgetPageAbstract(parent)
+    , mMatchCondition(AndCondition)
+    , mSieveGraphicalModeWidget(graphicalModeWidget)
 {
     QVBoxLayout *topLayout = new QVBoxLayout(this);
     topLayout->setMargin(0);
@@ -119,7 +120,6 @@ void SieveScriptBlockWidget::slotAddBlock()
 
 void SieveScriptBlockWidget::setPageType(PageType type)
 {
-
     if (pageType() != type) {
         SieveWidgetPageAbstract::setPageType(type);
         switch (type) {
@@ -172,8 +172,12 @@ void SieveScriptBlockWidget::updateWidget()
     mAddBlockType->setEnabled(mMatchCondition != AllCondition);
 }
 
-void SieveScriptBlockWidget::generatedScript(QString &script, QStringList &requires)
+void SieveScriptBlockWidget::generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop)
 {
+    QString indentation;
+    if (inForEveryPartLoop) {
+        indentation = AutoCreateScriptUtil::indentation();
+    }
     bool onlyActions = false;
     if (mMatchCondition == AllCondition) {
         onlyActions = true;
@@ -183,13 +187,13 @@ void SieveScriptBlockWidget::generatedScript(QString &script, QStringList &requi
     } else {
         QString conditionStr;
         int numberOfCondition = 0;
-        mScriptConditionLister->generatedScript(conditionStr, numberOfCondition, requires);
+        mScriptConditionLister->generatedScript(conditionStr, numberOfCondition, requires, inForEveryPartLoop);
         const bool hasUniqCondition = (numberOfCondition == 1);
         QString filterStr;
         QString blockStr;
         switch (pageType()) {
         case BlockIf:
-            blockStr = QStringLiteral("if ");
+            blockStr = indentation + QStringLiteral("if ");
             break;
         case BlockElsIf:
             blockStr = QStringLiteral("elsif ");
@@ -215,14 +219,14 @@ void SieveScriptBlockWidget::generatedScript(QString &script, QStringList &requi
             script += filterStr + conditionStr;
         }
         if (hasUniqCondition) {
-            script += QLatin1String("{\n");
+            script += indentation + QLatin1String("{\n");
         } else {
-            script += QLatin1String(")\n{\n");
+            script += indentation + QStringLiteral(")\n%1{\n").arg(indentation);
         }
     }
-    mScriptActionLister->generatedScript(script, requires, onlyActions);
+    mScriptActionLister->generatedScript(script, requires, onlyActions, inForEveryPartLoop);
     if (!onlyActions) {
-        script += QLatin1String("} ");
+        script += indentation + QLatin1String("} ");
     }
 }
 
@@ -242,7 +246,14 @@ void SieveScriptBlockWidget::updateCondition()
     updateWidget();
 }
 
-void SieveScriptBlockWidget::loadScript(const QDomElement &element, bool onlyActions, QString &error)
+void SieveScriptBlockWidget::loadLocalVariable(const SieveGlobalVariableActionWidget::VariableElement &var)
+{
+    mScriptActionLister->loadLocalVariable(var);
+    mMatchCondition = AllCondition;
+    updateCondition();
+}
+
+void SieveScriptBlockWidget::loadScript(QXmlStreamReader &element, bool onlyActions, QString &error)
 {
     if (onlyActions) {
         mScriptActionLister->loadScript(element, true, error);
@@ -250,39 +261,35 @@ void SieveScriptBlockWidget::loadScript(const QDomElement &element, bool onlyAct
         updateCondition();
     } else {
         bool uniqueTest = false;
-        QDomNode node = element.firstChild();
-        while (!node.isNull()) {
-            QDomElement e = node.toElement();
-            if (!e.isNull()) {
-                const QString tagName = e.tagName();
-                if (tagName == QLatin1String("test")) {
-                    bool notCondition = false;
-                    if (e.hasAttribute(QStringLiteral("name"))) {
-                        const QString typeCondition = e.attribute(QStringLiteral("name"));
-                        if (typeCondition == QLatin1String("anyof")) {
-                            mMatchCondition = OrCondition;
-                        } else if (typeCondition == QLatin1String("allof")) {
-                            mMatchAll->setChecked(true);
-                        } else {
-                            if (typeCondition == QLatin1String("not")) {
-                                notCondition = true;
-                            }
-                            uniqueTest = true;
-                            mMatchCondition = OrCondition;
+        while (element.readNextStartElement()) {
+            const QStringRef tagName = element.name();
+            if (tagName == QLatin1String("test")) {
+                bool notCondition = false;
+                if (element.attributes().hasAttribute(QStringLiteral("name"))) {
+                    const QString typeCondition = element.attributes().value(QStringLiteral("name")).toString();
+                    if (typeCondition == QLatin1String("anyof")) {
+                        mMatchCondition = OrCondition;
+                    } else if (typeCondition == QLatin1String("allof")) {
+                        mMatchAll->setChecked(true);
+                    } else {
+                        if (typeCondition == QLatin1String("not")) {
+                            notCondition = true;
                         }
-                        updateCondition();
+                        uniqueTest = true;
+                        mMatchCondition = OrCondition;
                     }
-                    mScriptConditionLister->loadScript(e, uniqueTest, notCondition, error);
-                } else if (tagName == QLatin1String("block")) {
-                    mScriptActionLister->loadScript(e, false, error);
+                    updateCondition();
+                }
+                mScriptConditionLister->loadScript(element, uniqueTest, notCondition, error);
+            } else if (tagName == QLatin1String("block")) {
+                mScriptActionLister->loadScript(element, false, error);
+            } else {
+                if (tagName != QLatin1String("crlf")) {
+                    qCDebug(LIBKSIEVE_LOG) << " e.tag" << tagName;
                 } else {
-                    if (tagName != QLatin1String("crlf")) {
-                        qCDebug(LIBKSIEVE_LOG) << " e.tag" << tagName;
-                    }
+                    element.skipCurrentElement();
                 }
             }
-            node = node.nextSibling();
         }
     }
 }
-
