@@ -51,9 +51,9 @@
 using namespace KSieveUi;
 
 SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
-    : QWidget(parent),
-      mMode(TextMode),
-      mModified(false)
+    : QWidget(parent)
+    , mMode(TextMode)
+    , mModified(false)
 {
     QVBoxLayout *lay = new QVBoxLayout;
 #if !defined(NDEBUG)
@@ -262,7 +262,6 @@ void SieveEditorWidget::print()
         qCDebug(LIBKSIEVE_LOG) << " Unknown mode";
         break;
     }
-
 }
 
 void SieveEditorWidget::printPreview()
@@ -398,6 +397,8 @@ void SieveEditorWidget::slotShareScript()
             }
         }
         delete zip;
+    } else {
+        qCWarning(LIBKSIEVE_LOG) << "Impossible to open temp file";
     }
 }
 
@@ -419,14 +420,14 @@ void SieveEditorWidget::changeMode(EditorMode mode)
             mCheckSyntax->setEnabled(false);
         }
         Q_EMIT modeEditorChanged(mode);
-        changeModeEditor(isTextMode);
+        Q_EMIT changeModeEditor(isTextMode);
         changeSwitchButtonText();
     }
 }
 
 void SieveEditorWidget::changeSwitchButtonText()
 {
-    mSwitchMode->setText((mMode == TextMode) ?  i18n("Simple Mode") : i18n("Advanced Mode"));
+    mSwitchMode->setText((mMode == TextMode) ? i18n("Simple Mode") : i18n("Advanced Mode"));
 }
 
 void SieveEditorWidget::slotEnableButtonOk(bool b)
@@ -610,26 +611,28 @@ void SieveEditorWidget::slotSwitchToGraphicalMode()
 void SieveEditorWidget::slotSwitchMode()
 {
     switch (mMode) {
-    case TextMode: {
+    case TextMode:
+    {
         bool result = false;
-        const QDomDocument doc = ParsingUtil::parseScript(mTextModeWidget->currentscript(), result);
+        const QString doc = ParsingUtil::parseScript(mTextModeWidget->currentscript(), result);
         if (result) {
             QString error;
             mGraphicalModeWidget->loadScript(doc, error);
-            mTextModeWidget->hideEditorWarning();
             if (!error.isEmpty()) {
                 mTextModeWidget->setParsingEditorWarningError(mTextModeWidget->currentscript(), error);
                 mTextModeWidget->showParsingEditorWarning();
             } else {
+                mTextModeWidget->hideEditorWarning();
                 changeMode(GraphicMode);
             }
         } else {
             mTextModeWidget->showEditorWarning();
-            qCDebug(LIBKSIEVE_LOG) << "cannot parse file";
+            qCDebug(LIBKSIEVE_LOG) << "Impossible to parse file";
         }
         break;
     }
-    case GraphicMode: {
+    case GraphicMode:
+    {
         const QString script = mGraphicalModeWidget->currentscript();
         changeMode(TextMode);
         mTextModeWidget->setScript(script);
